@@ -1,4 +1,5 @@
 import math
+import os
 
 from dataclasses import dataclass
 from typing import Any, Optional, Tuple
@@ -6,6 +7,7 @@ from typing import Any, Optional, Tuple
 import torch
 from einops import rearrange, repeat
 from torch import Tensor
+from transformers import PerceiverConfig as HuggingfacePerceiverConfig, PerceiverForImageClassificationFourier
 
 from perceiver.model.core import (
     ClassificationDecoderConfig,
@@ -18,6 +20,12 @@ from perceiver.model.core import (
     PerceiverEncoder,
     PerceiverIO,
 )
+from perceiver.model.core.convert import (
+    copy_cross_attention_layer_params,
+    copy_param,
+    copy_params,
+    copy_self_attention_block_params,
+)
 
 
 @dataclass
@@ -134,6 +142,16 @@ class ImageClassifier(PerceiverIO):
         )
         super().__init__(encoder, decoder)
 
+        if config.params is None:
+            pass
+        elif os.path.isfile(config.params):
+            self.load_state_dict(torch.load(config.params))
+        else:
+            # import model params from Huggingface Perceiver
+            model = PerceiverForImageClassificationFourier.from_pretrained(config.params)
+            copy_encoder_params(model, self.encoder)
+            copy_decoder_params(model, self.decoder)
+
 
 class LitImageClassifier(LitClassifier):
     def __init__(self, encoder: ImageEncoderConfig, decoder: ClassificationDecoderConfig, *args: Any, **kwargs: Any):
@@ -146,9 +164,65 @@ class LitImageClassifier(LitClassifier):
                 num_latent_channels=self.hparams.num_latent_channels,
                 activation_checkpointing=self.hparams.activation_checkpointing,
                 activation_offloading=self.hparams.activation_offloading,
+                params=self.hparams.params,
             )
         )
 
     def forward(self, batch):
         y, x = batch["label"], batch["image"]
         return self.model(x), y
+
+
+def copy_output_adapter_params(src: PerceiverForImageClassificationFourier, tgt: ClassificationOutputAdapter):
+    query_src = src.perceiver.decoder.decoder.output_position_encodings.position_embeddings
+    query_tgt = tgt._output_query
+
+    with torch.no_grad():
+        query_tgt.copy_(query_src)
+
+    copy_params(src.perceiver.decoder.decoder.final_layer, tgt.linear)
+
+
+def copy_encoder_params(src: PerceiverForImageClassificationFourier, tgt: PerceiverEncoder):
+    copy_param(src.perceiver.embeddings.latents, tgt.latent)
+    copy_cross_attention_layer_params(src.perceiver.encoder.cross_attention, tgt.cross_attn_1, query_residual=True)
+    copy_self_attention_block_params(src.perceiver.encoder.self_attends, tgt.self_attn_1)
+
+
+def copy_decoder_params(src: PerceiverForImageClassificationFourier, tgt: PerceiverDecoder):
+    copy_cross_attention_layer_params(
+        src.perceiver.decoder.decoder.decoding_cross_attention, tgt.cross_attn, query_residual=True
+    )
+    copy_output_adapter_params(src, tgt.output_adapter)
+
+
+def convert_config(
+    config: HuggingfacePerceiverConfig,
+) -> PerceiverConfig[ImageEncoderConfig, ClassificationDecoderConfig]:
+    assert config.hidden_act == "gelu"
+
+    encoder_config = ImageEncoderConfig(
+        image_shape=(224, 224, 3),
+        num_frequency_bands=64,
+        num_cross_attention_heads=config.num_cross_attention_heads,
+        num_self_attention_heads=config.num_self_attention_heads,
+        num_self_attention_layers_per_block=config.num_self_attends_per_block,
+        num_self_attention_blocks=config.num_blocks,
+        dropout=config.attention_probs_dropout_prob,
+        init_scale=config.initializer_range,
+    )
+    decoder_config = ClassificationDecoderConfig(
+        num_classes=config.num_labels,
+        num_output_query_channels=config.d_latents,
+        num_cross_attention_heads=config.num_cross_attention_heads,
+        cross_attention_residual=True,
+        dropout=config.attention_probs_dropout_prob,
+        init_scale=config.initializer_range,
+    )
+    return PerceiverConfig(
+        encoder_config,
+        decoder_config,
+        num_latents=config.num_latents,
+        num_latent_channels=config.d_latents,
+        params=config.name_or_path,
+    )
